This is a subfunction of `cluster_gen` that performs cluster sampling where only the lowest-level individuals (e.g. students) fill out questionnaires.
cluster_gen_together(
n_levels,
n,
N,
sum_pop,
calc_weights,
sampling_method,
cluster_labels,
resp_labels,
collapse,
n_X,
n_W,
cat_prop,
c_mean,
sigma,
cor_matrix,
rho,
verbose,
...
)number of cluster levels
numeric vector with the number of sampled observations (clusters or subjects) on each level
list of numeric vector with the population size of each *sampled* cluster element on each level
total population at the lowest level (sampled or not)
if `TRUE`, sampling weights are calculated
can be "SRS" for Simple Random Sampling or "PPS" for Probabilities Proportional to Size
character vector with the names of each cluster level
character vector with the names of the questionnaire respondents on each level
if `TRUE`, function output contains only one data frame with all answers
list of `n_X` per cluster level
list of `n_W` per cluster level
list of cumulative proportions for each item. If theta
= TRUE, the first element of cat_prop must be a scalar 1, which
corresponds to the theta.
vector of means for the continuous variables or list of vectors for the continuous variables for each level
vector of standard deviations for the continuous variables or list of vectors for the continuous variables for each level
correlation matrix or list of correlation matrices per PSU
intraclass correlation (scalar, vector or list)
if `TRUE`, prints output messages
Additional parameters to be passed to `questionnaire_gen()`
cluster_gen cluster_gen_separate cluster_gen_together