Learn R Programming

lsasim (version 2.1.4)

label_respondents: Label respondents

Description

This function nerated level label combinations for each respondent

Usage

label_respondents(
  n_obs,
  cluster_labels = names(n_obs),
  add_last_level = FALSE,
  apply_labels = TRUE
)

Value

Data frame with the combinations of IDs from all levels

Arguments

n_obs

list with the number of elements per level

cluster_labels

character vector with the names of each cluster level

add_last_level

if `TRUE` (not default), adds the last level to the output table

apply_labels

if `TRUE`, applies labels (column names) to data cells