A dataset containing indicators associating those PISA 2012 mathematics item blocks to the PISA 2012 mathematics standard test booklet set.
pisa2012_math_bookletA data frame with 13 rows and 10 variables:
Booklet name.
Indicator specifying those test booklets that use item block 1.
Indicator specifying those test booklets that use item block 2.
Indicator specifying those test booklets that use item block 3.
Indicator specifying those test booklets that use item block 4.
Indicator specifying those test booklets that use item block 5.
Indicator specifying those test booklets that use item block 6.
Indicator specifying those test booklets that use item block 7.
Indicator specifying those test booklets that use item block 8.
Indicator specifying those test booklets that use item block 9.