Recalculate final weights given the replicate weights
recalc_final_weights(data, w_cols, replicate_weight = 1, reorder = TRUE)input data with recalculated final weights, incorporating the replicate weights
dataset
columns containing the weights
scalar with the replicate weights
if TRUE, reorders the dataset so that the replicate weights appear before the final weights