rzeropois: Generate data from a Zero-truncated Poisson
Description
Random generation of one observation of a random variable distributed as a Zero-truncated Poisson
Usage
rzeropois(lambda)
Arguments
lambda
corresponds to the lambda parameter of a Poisson
Details
The zero-truncated Poisson (a.k.a. conditional Poisson or positive Poisson) distribution is a discrete probability distribution whose support is the set of positive integers.