This function nerated level label combinations for each respondent
label_respondents(
n_obs,
cluster_labels = names(n_obs),
add_last_level = FALSE,
apply_labels = TRUE
)Data frame with the combinations of IDs from all levels
list with the number of elements per level
character vector with the names of each cluster level
if `TRUE` (not default), adds the last level to the output table
if `TRUE`, applies labels (column names) to data cells