Learn R Programming

lsasim (version 2.1.4)

pisa2012_math_booklet: PISA 2012 mathematics item block - test booklet indicator matrix

Description

A dataset containing indicators associating those PISA 2012 mathematics item blocks to the PISA 2012 mathematics standard test booklet set.

Usage

pisa2012_math_booklet

Arguments

Format

A data frame with 13 rows and 10 variables:

booklet

Booklet name.

b1

Indicator specifying those test booklets that use item block 1.

b2

Indicator specifying those test booklets that use item block 2.

b3

Indicator specifying those test booklets that use item block 3.

b4

Indicator specifying those test booklets that use item block 4.

b5

Indicator specifying those test booklets that use item block 5.

b6

Indicator specifying those test booklets that use item block 6.

b7

Indicator specifying those test booklets that use item block 7.

b8

Indicator specifying those test booklets that use item block 8.

b9

Indicator specifying those test booklets that use item block 9.